@@ -94,7 +94,7 @@ async def _process_bulk_chunk(
 
     try:
         # send the actual request
-        resp = await client.bulk("\n".join(bulk_actions) + "\n", *args, **kwargs)
+        resp = await client.bulk(body="\n".join(bulk_actions) + "\n", *args, **kwargs)
     except TransportError as e:
         gen = _process_bulk_chunk_error(
             error=e,
