@@ -457,6 +457,28 @@ class TestRequestsHttpConnection(TestCase):
 
         return dummy_session
 
+    def test_aws_signer_url_with_querystring_and_custom_header(self) -> None:
+        region = "us-west-2"
+
+        import requests
+        from botocore.awsrequest import AWSRequest
+
+        from opensearchpy.helpers.signer import RequestsAWSV4SignerAuth
+
+        with patch(
+            "botocore.awsrequest.AWSRequest", side_effect=AWSRequest
+        ) as mock_aws_request:
+
+            auth = RequestsAWSV4SignerAuth(self.mock_session(), region)
+            prepared_request = requests.Request(
+                "GET", "http://localhost/?foo=bar", headers={"host": "otherhost:443"}
+            ).prepare()
+            auth(prepared_request)
+
+            mock_aws_request.assert_called_with(
+                method="GET", url="http://otherhost:443/?foo=bar", data=None
+            )
+
     def test_aws_signer_as_http_auth(self) -> None:
         region = "us-west-2"
 
@@ -508,9 +530,70 @@ class TestRequestsHttpConnection(TestCase):
         ).prepare()
         auth(prepared_request)
         self.assertEqual(mock_sign.call_count, 1)
+        mock_sign.assert_called_with(
+            method="GET",
+            url="http://localhost/?key1=value1&key2=value2",
+            body=None,
+            headers={},
+        )
+
+    def test_aws_signer_consitent_url(self) -> None:
+        region = "us-west-2"
+
+        from typing import Any, Collection, Mapping, Optional, Union
+
+        from opensearchpy import OpenSearch
+        from opensearchpy.helpers.signer import RequestsAWSV4SignerAuth
+
+        # Store URLs for comparison
+        signed_url = None
+        sent_url = None
+
+        doc_id = "doc_id:with!special*chars%3A"
+        quoted_doc_id = "doc_id%3Awith%21special*chars%253A"
+        url = f"https://search-domain.region.es.amazonaws.com:9200/index/_doc/{quoted_doc_id}"
+
+        # Create a mock signer class to capture the signed URL
+        class MockSigner(RequestsAWSV4SignerAuth):
+            def __call__(self, prepared_request):  # type: ignore
+                nonlocal signed_url
+                if isinstance(prepared_request, str):
+                    signed_url = prepared_request
+                else:
+                    signed_url = prepared_request.url
+                return prepared_request
+
+        # Create a mock connection class to capture the sent URL
+        class MockConnection(RequestsHttpConnection):
+            def perform_request(  # type: ignore
+                self,
+                method: str,
+                url: str,
+                params: Optional[Mapping[str, Any]] = None,
+                body: Optional[bytes] = None,
+                timeout: Optional[Union[int, float]] = None,
+                allow_redirects: Optional[bool] = True,
+                ignore: Collection[int] = (),
+                headers: Optional[Mapping[str, str]] = None,
+            ) -> Any:
+                nonlocal sent_url
+                sent_url = f"{self.host}{url}"
+                return 200, {}, "{}"
+
+        auth = MockSigner(self.mock_session(), region)
+
+        client = OpenSearch(
+            hosts=[{"host": "search-domain.region.es.amazonaws.com"}],
+            http_auth=auth(url),
+            use_ssl=True,
+            verify_certs=True,
+            connection_class=MockConnection,
+        )
+        client.index(index="index", body={"test": "data"}, id=doc_id)
         self.assertEqual(
-            mock_sign.call_args[0],
-            ("GET", "http://localhost/?key1=value1&key2=value2", None),
+            signed_url,
+            sent_url,
+            "URLs don't match",
         )
 
 
